@@ -10,7 +10,7 @@ def get_session(alias):
     """Returns a database session for a connection identified by
     the given `alias`.
     """
-    return _connections[alias].get_session()
+    return _connections.get_session(alias)
 
 
 def add_connection(alias, dsn):
